// Fichier Propulsion.H
/////////////////////////////////////////////////////////

/********************************************************
 *                                                      *
 *                Code source de la librairie           *
 *					de la carte principale 				*
 *                                                      *
 * .Date de cration : 29/12/07                         *
 * .Auteur : Philippe Lucidarme                         *       
 *                                                      *
 * .Descriptions :                                      *
 *      - code des fonctions pour la carte principale   *
 *                                                      *
 *                                                      *
 * .Remarques :                                         *
 *                                                      *
 ********************************************************/
#ifndef __PROPULSION_H__
#define __PROPULSION_H__


#define			PI				3.141592653589793	// Constante Pi


typedef struct{										// Structure permettant de stocker des coordonnes
	int X; int Y; float psi; 
} TGeom;


// --------------------------------------------------------------------------
/* Retourne vrai si un mouvement est en cours (la cible n'est pas atteinte et
 * le robot n'est pas bloqu)
*/
char IsMove_Propulsion(void);


// --------------------------------------------------------------------------
/* Avance (ou recule) de distance en mm
 * Arguments : 
 *  Distance  parcourir en ligne droite
 *  Vitesse de dplacement (si c'est positif on avance, sinon on recule)
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractre reus ne corresponde pas aux caractre attendus
*/
int ToutDroit_Propulsion (int Distance, int Vitesse);





// --------------------------------------------------------------------------
/* Oriente le robot vers l'angle pass en paramtre
 * Arguments : 
 *  Orientation dsire du robot en radians
 *  Vitesse angulaire maximum de rotation
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractre reus ne corresponde pas aux caractre attendus
*/
int Angle_Propulsion (float Angle, int VitesseMax);





// --------------------------------------------------------------------------
/* Envoie le robot vers le point X,Y
 * Arguments : 
 *  Position en X
 *  Position en Y 
 *  Vitesse de dplacement
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractre reus ne corresponde pas aux caractre attendus
*/
int GotoXY_Propulsion (int X, int Y, int V);





// --------------------------------------------------------------------------
/* Force la position courante du robot
 * Arguments : 
 *  Position en X
 *  Position en Y
 *  Orientation du robot (en rad*1000)
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractre reus ne corresponde pas aux caractre attendus
*/
int Force_Propulsion (int X, int Y, int A);







// --------------------------------------------------------------------------
/* Envoie une commande directe sur les moteurs
 * Arguments :
 *  - Le premier paramtre est la vitesse du moteur gauche [-1023,+1023]
 *  - Le second paramtre est la vitesse du moteur droit [-1023,+1023]
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass 
 */
int Direct_Propulsion (int VitG, int VitD);



// --------------------------------------------------------------------------
/* Commande les moteurs en mode direct asservi
 * Arguments : aucun 
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractre reus ne corresponde pas aux caractre attendus
*/
int Direct_Asservi_Propulsion (int VitG,int VitD);




// --------------------------------------------------------------------------
/* Commande les moteurs en polaire : vitesse linaire et vitesse angulaire
 * Arguments :
 *  - Le premier paramtre est la vitesse linaire [-100,+100]
 *  - Le second paramtre est la vitesse angulaire [-50,+50]
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractre reus ne corresponde pas aux caractre attendus
*/
int Polaire_Propulsion (int VitL,int VitA);





// --------------------------------------------------------------------------
/* Envoie une commande directe sur les moteurs
 * Arguments :
 *  - Le premier paramtre est la vitesse du moteur gauche [-1023,+1023]
 *  - Le second paramtre est la vitesse du moteur droit [-1023,+1023]
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractre reus ne corresponde pas aux caractre attendus
*/
int Stop_Propulsion (void);






// --------------------------------------------------------------------------
/* Lit l'tat (tat + position + orientation) de la carte propulsion
 * Arguments :
 *  - Le premier paramtre est un pointeur vers l'tat de la carte
 *  - Le second paramtre est un pointeur vers la coordonne en X
 *  - Le troisime paramtre est un pointeur vers la coordonne en Y
 *  - Le dernier paramtre est un pointeur vers l'orientation
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Erreur de CRC
*/
int Info_Propulsion (int *S,int *X,int *Y,int *A);






// --------------------------------------------------------------------------
/* Lit l'tat  de la carte propulsion
 * Arguments : aucun
 * 
 * Paramtre renvoy : 
 *   Etat courant de la carte
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Erreur de CRC
*/
char Etat_Propulsion (void);





// --------------------------------------------------------------------------
/* Retourne la position en X du robot
 * Arguments : aucun
 * 
 * Paramtre renvoy : 
 *   Position du robot en X
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Erreur de CRC
*/
int X_Propulsion (void);



// --------------------------------------------------------------------------
/* Retourne la position en Y du robot
 * Arguments : aucun
 * 
 * Paramtre renvoy : 
 *   Position du robot en Y
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Erreur de CRC
*/
int Y_Propulsion (void);



/* Retourne l'orientation du robot
 * Arguments : aucun
 * 
 * Paramtre renvoy : 
 *   Orientation du robot (x1000)
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Erreur de CRC
*/
int A_Propulsion (void);


// --------------------------------------------------------------------------
/* Effectue un chek-up de la propulsion
 * Arrte les moteurs   								(erreur 1)
 * Force la position du robot  						 	(erreur 2)
 * Lit la nouvelle position 							(erreur 3)
 * Compare la nouvelle position  la position force	(erreur 4)
 * Force en position de dpart							(erreur 5)
 * Avance de 3,4 cm										(erreur 6)
 * S'oriente 				  						 	(erreur 7)
 * Arrte les moteur									(erreur 8)
 * Pas de problme : on retourne 0 
*/
unsigned char Check_Up_Propulsion (unsigned char couleur);





// --------------------------------------------------------------------------
/* Recalibrage du robot en X,Y et en A par rapport  la postion rel
 * Arguments : 
 *  DeltaX
 *  DeltaY
 *  DeltaA (en radians * 1000)
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
 *  -2 : Les caractres reus ne correspondent pas aux caractres attendus
*/
int Recalibrage_Robot (int dX, int dY, int dA);



#endif
