// Fichier serial.H
/////////////////////////////////////////////////////////

/********************************************************
 *                                                      *
 *                Code source de la librairie           *
 *					de la carte principale 				*
 *                                                      *
 * .Date de cration : 29/12/07                         *
 * .Auteur : Philippe Lucidarme                         *       
 *                                                      *
 * .Descriptions :                                      *
 *      - code des fonctions pour la carte principale   *
 *                                                      *
 *                                                      *
 * .Remarques :                                         *
 *                                                      *
 ********************************************************/
#ifndef __SERIAL_H
#define __SERIAL_H



#define		TRIS_RX			TRISCbits.TRISC7		// Ligne de rception des donnes
#define 	TRIS_TX			TRISCbits.TRISC6		// Ligne d'envoie des donnes
	
#define 	DELAY_USART		Delay10TCYx(50);		// Dlay entre l'envoie de 2 caractres





// --------------------------------------------------------------------------
/* Initialise la carte propulsion (liaison srie)
 *  Pas de paramtre
*/
void Serial_Init(void);


// --------------------------------------------------------------------------
/* Envoie une srie de 0 et de 0xFF pour resynchroniser la carte propulsion
 *  Pas de paramtre
*/
void Serial_ReStart(void);




// --------------------------------------------------------------------------
/* Calcul le CRC de la trame
 *  Le premier paramtre est un pointeur vers le premier caractre de la trame
 *  Le second est le nombre de caractres
*/
unsigned char CRC (unsigned char* Trame,int NbCar);
	



// --------------------------------------------------------------------------
/* Envoyer la trame sur la liaison srie
 *  Le premier est un pointeur vers le premier caractre de la trame
 *  Le second paramtre est le nombre de caractre  envoyer 
*/
void Envoyer_Trame(unsigned char* Trame, char NbCar);



// --------------------------------------------------------------------------
/* Recevoir une trame sur la liaison srie
 *  Le premier est un pointeur vers le premier caractre de la trame
 *  Le second paramtre est le nombre de caractre  envoyer 
 *  Le dernier paramtre est la dure du TimeOut en ms
 * 
 * Paramtre renvoy : 
 *   0 : Tout s'est bien pass
 * 	-1 : On a pas reu tous les caractres avant la fin du TimeOut 
*/
char Recevoir_Trame(unsigned char* Trame, char NbCar, unsigned long int TimeOut);




// --------------------------------------------------------------------------
/* Vide le buffer de la liaison srie et supprime les erreurs ventuelles
 *  Aucun paramtre
*/
void Vide_Buffer_USART(void);

#endif