// Fichier Robot.c
/////////////////////////////////////////////////////////

/********************************************************
 *                                                      *
 *                Code source de la librairie           *
 *					de la carte principale 				*
 *                                                      *
 * .Date de cration : 29/12/07                         *
 * .Auteur : Philippe Lucidarme                         *       
 *                                                      *
 * .Descriptions :                                      *
 *      - code des fonctions pour la carte principale   *
 *                                                      *
 *                                                      *
 * .Remarques :                                         *
 *                                                      *
 ********************************************************/



#define 	ADR_I2C_TOURELLE		0x2C		// Adresse IC du rouleau droit



// --------------------------------------------------------------------------
/* Dmarre la tourelle la tourelle
 * Paramtre retourn : 
 *   0 : Tout s'est bien pass
 * 	-1 : Une collision s'est produite sur le BUS IC ou l'esclave n'a pas renvoy d'acknoledgment aprs l'adresse
 *  -2 : L'esclave n'a pas envoy d'acknoledgement aprs une donne
*/
int Start_Tourelle(void);



// --------------------------------------------------------------------------
/* Stoppe la tourelle
 * Paramtre retourn : 
 *   0 : Tout s'est bien pass
 * 	-1 : Une collision s'est produite sur le BUS IC ou l'esclave n'a pas renvoy d'acknoledgment aprs l'adresse
 *  -2 : L'esclave n'a pas envoy d'acknoledgement aprs une donne
*/
int Stop_Tourelle(void);



// --------------------------------------------------------------------------
/* Retourne la distance avec le robot adverse
 *  entre 0 et 255 si tout s'est bien pass
 *  -1 en cas de problme dans la transmission
*/
int Distance_Robot_Adverse(void);



// --------------------------------------------------------------------------
/* Retourne l'orientation absolue du robot adverse
 *  Valeur comprise entre -PI et +PI  
*/
float Angle_Absolu_Robot_Adverse (void);


// --------------------------------------------------------------------------
/* Retourne l'angle avec le robot adverse
 *  entre 0 et 255 si tout s'est bien pass
 *  -1 en cas de problme dans la transmission
*/
int Angle_Robot_Adverse(void);


// --------------------------------------------------------------------------
/* Retourne la vitesse angulaire du robot adverse
 *  entre -128 et 128 si tout s'est bien pass
 *  >0 Le robot adverse se dplace dans le sens trigo
 *  <0 Le robot adverse se dplace dans le sens horaire
 *  0xFFFF en cas de problme dans la transmission
*/
int Vitesse_Robot_Adverse(void);



// --------------------------------------------------------------------------
/* Effectue un chek-up de la tourelle
 * Vrifie qu'on ne reoit pas d'missions parasites 	(erreur 1)
 * Localise l'adversaire ... ou attends un clic			(erreur 2)
 *  ... et vrifie qu'il est du bon ct 			  	(erreur 3)
 * Pas de problme : on retourne 0 
*/
unsigned char Check_Up_Tourelle(unsigned char couleur);

